# chibihash
[![CI](https://github.com/jimexist/chibihash/actions/workflows/ci.yaml/badge.svg)](https://github.com/jimexist/chibihash/actions/workflows/ci.yaml)
[![Release](https://github.com/jimexist/chibihash/actions/workflows/build.yaml/badge.svg)](https://github.com/jimexist/chibihash/actions/workflows/build.yaml)
[![PyPI version](https://badge.fury.io/py/chibihash.svg)](https://badge.fury.io/py/chibihash)


## How to use

```bash
pip install chibihash
```

```python
from chibihash import chibihash64

chibihash64(b"hello")
```

## References

- [Original implementation](https://github.com/N-R-K/ChibiHash/blob/master/chibihash64.h)
